# Guardrails Hub Types

Internal data structures for the Guardrails Hub.

## Installation
```sh
pip install guardrails-hub-types
```

## Development
```sh
git clone https://github.com/guardrails-ai/hub-types.git

cd hub-types

npm ci

npm run openapi-gen

bash ./py-build.sh
```

## Documentation For Models

 - [Applicator](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Applicator.md);
 - [Content](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Content.md);
 - [Contributor](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Contributor.md);
 - [Core](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Core.md);
 - [FormatAnnotation](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/FormatAnnotation.md);
 - [Manifest](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Manifest.md);
 - [ManifestParameters](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/ManifestParameters.md);
 - [MetaData](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/MetaData.md);
 - [ModelAuth](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/ModelAuth.md);
 - [ModelSchema](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/ModelSchema.md);
 - [Repository](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Repository.md);
 - [SimpleTypes](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/SimpleTypes.md);
 - [Tags](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Tags.md);
 - [Unevaluated](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Unevaluated.md);
 - [Validation](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/Validation.md);
 - [ValidationType](https://github.com/guardrails-ai/hub-types/tree/main/resources/py/docs/ValidationType.md);
  